reStructuredText file
======================

`I’m an inline-style link <https://www.google.com>`__

`I’m an inline-style link that 404s <http://example.com/404>`__

`I’m an inline-style link with title <https://www.google.com>`__

`I’m a reference-style link <https://www.mozilla.org>`__

`I’m a relative reference to a repository file <./rst.rst>`__

`You can use numbers for reference-style link
definitions <http://slashdot.org>`__

Or leave it empty and use the `link text
itself <https://www.w3.org>`__.

URLs will automatically get turned into
links. http://www.example.com or http://www.example.com/404.

Some text to show that the reference links can follow later.
